@@ -5,6 +5,18 @@
 #'
 #' @param result_daily_response a list with three objects as produced by
 #' \code{\link{daily_response}} function
+#' @param reference_window character string, the reference_window argument describes,
+#' how each calculation is referred. There are three different options: 'start'
+#' (default), 'end' and 'middle'. If the reference_window argument is set to 'start',
+#' then each calculation is related to the starting day of window. If the
+#' reference_window argument is set to 'middle', each calculation is related to the
+#' middle day of window calculation. If the reference_window argument is set to
+#' 'end', then each calculation is related to the ending day of window calculation.
+#' For example, if we consider correlations with window from DOY 15 to DOY 35. If
+#' reference window is set to ‘start’, then this calculation will be related to the
+#' DOY 15. If the reference window is set to ‘end’, then this calculation will be
+#' related to the DOY 35. If the reference_window is set to 'middle', then this
+#' calculation is related to DOY 25.
 #'
 #' @return A ggplot2 object containing the heatmap display
 #'
@@ -33,20 +45,19 @@
 #'
 #' @keywords internal
 
-plot_heatmap <- function(result_daily_response){
+plot_heatmap <- function(result_daily_response, reference_window = "start"){
 
   # Extracting a matrix from a list and converting it into a data frame
   result_daily_element1 <- data.frame(result_daily_response [[1]])
 
+
   # Creating a nice string that will be used to generate ggplot Legend
-  if  (result_daily_response[[3]] == "r.squared"){
-    temp_string <- "R squared"
+  if (result_daily_response[[2]] == "cor"){
+    temp_string <- "Correlation Coefficient"
+  } else if (result_daily_response[[3]] == "r.squared"){
+    temp_string <- "Explained Variance"
   } else if (result_daily_response[[3]] == "adj.r.squared"){
-    temp_string <- "Adjusted R squared"
-  } else if (result_daily_response[[2]] == "cor") {
-    temp_string <- "Correlation coefficient"
-  } else {
-    stop("Check your method and metrics")
+    temp_string <- "Adjusted Explained Variance"
   }
 
   # Data manipulation. The goal of this part is to prepare data for ggplot
@@ -119,7 +130,7 @@ plot_heatmap <- function(result_daily_response){
 
   # If previous_year == TRUE(function daily_response), different xlab
   # is needed
-  if (ncol(result_daily_element1) > 366) {
+  if (ncol(result_daily_element1) > 367) {
     final_plot <- suppressWarnings(final_plot +
       annotate(fontface = "bold", label = 'Previous Year', geom = 'label',
               x = 366 - ncol(result_daily_element1) / 12.8,
@@ -136,57 +147,33 @@ plot_heatmap <- function(result_daily_response){
   }
 
 
-
-
-  # Here we add titles, based on different methods
-  if (is.na(result_daily_response[[4]])) {
-
-
-    if (result_daily_response [[2]] == "cor") {
-      final_plot <- final_plot +
-        ggtitle(paste("Method: Correlation Coefficients"))
-    }
-
-    if (result_daily_response [[2]] == "lm") {
-      final_plot <- final_plot +
-        ggtitle(paste("Method: Linear Regression"))
-    }
-
-    if (result_daily_response [[2]] == "brnn") {
-      final_plot <- final_plot +
-        ggtitle(paste("Method: ANN With Bayesian Regularization"))
-    }
-
+  if (ncol(result_daily_element1) > 367){
+    x_lab <- "Day of Year  (Including Previous Year)"
+  } else if (ncol(result_daily_element1) <= 367){
+    x_lab <- "Day of Year"
   }
 
-
-
-  if (!is.na(result_daily_response[[4]])) {
-
-
-    if (result_daily_response [[2]] == "cor") {
-      final_plot <- final_plot +
-        ggtitle(paste("Analysed Period:", result_daily_response[[4]],
-                      "\nMethod: Correlation Coefficients"))
-    }
-
-    if (result_daily_response [[2]] == "lm") {
-      final_plot <- final_plot +
-        ggtitle(paste("Analysed Period:", result_daily_response[[4]],
-                      "\nMethod: Linear Regression"))
-    }
-
-    if (result_daily_response [[2]] == "brnn") {
-      final_plot <- final_plot +
-        ggtitle(paste("Analysed Period:", result_daily_response[[4]],
-                      "\nMethod: ANN With Bayesian Regularization"))
-    }
-
+  if (result_daily_response[[2]] == 'cor'){
+    method_string <- paste0("\nMethod: Pearson Correlation")
+  } else if (result_daily_response[[2]] == 'lm'){
+    method_string <- paste0("\nMethod: Linear Regression")
+  } else if (result_daily_response[[2]] == 'brnn'){
+    method_string <- paste0("\nMethod: ANN with Bayesian Regularization")
   }
 
+  period_string <- paste0("\nAnalysed Period: ", result_daily_response[[4]])
 
+  if (reference_window == 'start'){
+    reference_string <- "\nDOY Reference of Each Calculation is the Beginning of the Window"
+  } else if (reference_window == 'end'){
+    reference_string <- "\nDOY Reference of Each Calculation is the End Day of the Window"
+  } else if (reference_window == 'middle'){
+    reference_string <- "\nDOY Reference of Each Calculation is the Middle Day of the Window"
+  }
 
-
+  final_plot <- final_plot +
+        xlab(x_lab) +
+        ggtitle(paste0(period_string, method_string, reference_string))
 
   final_plot
 }
